py_inspect_currentfunction method
Get the current Callable object on the stack of the most recent vectorcall.
Return NULL if not available.
NOTE: This function should be placed at the beginning of your bindings or you will get wrong result.
Implementation
py_StackRef py_inspect_currentfunction() {
return _py_inspect_currentfunction();
}